@@ -1,8 +1,18 @@
+#
+# This file is part of Apache-Singleton
+#
+# This software is copyright (c) 2009 by Michael Schout.
+#
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
+#
+
 package Apache::Singleton;
-$Apache::Singleton::VERSION = '0.16';
+$Apache::Singleton::VERSION = '0.17';
 # ABSTRACT: Singleton class for mod_perl
 
 use strict;
+use warnings;
 
 # load appropriate subclass
 if ($ENV{MOD_PERL}) {
@@ -66,7 +76,7 @@ Apache::Singleton - Singleton class for mod_perl
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -133,7 +143,7 @@ L<Class::Singleton>
 
 =head1 SOURCE
 
-The development version is on github at L<http://github.com/mschout/apache-singleton>
+The development version is on github at L<https://github.com/mschout/apache-singleton>
 and may be cloned from L<git://github.com/mschout/apache-singleton.git>
 
 =head1 BUGS
